@@ -128,12 +128,12 @@ class BatchClient(BaseClient):
         type: CETypeType,
         state: CEStateType = ...,
         unmanagedvCpus: int = ...,
-        computeResources: "ComputeResourceTypeDef" = ...,
+        computeResources: ComputeResourceTypeDef = ...,
         serviceRole: str = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateComputeEnvironmentResponseTypeDef:
         """
-        Creates an Batch compute environment.
+        .
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/batch.html#Batch.Client.create_compute_environment)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_batch/client/#create_compute_environment)
@@ -144,7 +144,7 @@ class BatchClient(BaseClient):
         *,
         jobQueueName: str,
         priority: int,
-        computeEnvironmentOrder: Sequence["ComputeEnvironmentOrderTypeDef"],
+        computeEnvironmentOrder: Sequence[ComputeEnvironmentOrderTypeDef],
         state: JQStateType = ...,
         schedulingPolicyArn: str = ...,
         tags: Mapping[str, str] = ...
@@ -160,7 +160,7 @@ class BatchClient(BaseClient):
         self,
         *,
         name: str,
-        fairsharePolicy: "FairsharePolicyTypeDef" = ...,
+        fairsharePolicy: FairsharePolicyTypeDef = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateSchedulingPolicyResponseTypeDef:
         """
@@ -283,7 +283,7 @@ class BatchClient(BaseClient):
         jobStatus: JobStatusType = ...,
         maxResults: int = ...,
         nextToken: str = ...,
-        filters: Sequence["KeyValuesPairTypeDef"] = ...
+        filters: Sequence[KeyValuesPairTypeDef] = ...
     ) -> ListJobsResponseTypeDef:
         """
         Returns a list of Batch jobs.
@@ -317,11 +317,11 @@ class BatchClient(BaseClient):
         type: JobDefinitionTypeType,
         parameters: Mapping[str, str] = ...,
         schedulingPriority: int = ...,
-        containerProperties: "ContainerPropertiesTypeDef" = ...,
-        nodeProperties: "NodePropertiesTypeDef" = ...,
-        retryStrategy: "RetryStrategyTypeDef" = ...,
+        containerProperties: ContainerPropertiesTypeDef = ...,
+        nodeProperties: NodePropertiesTypeDef = ...,
+        retryStrategy: RetryStrategyTypeDef = ...,
         propagateTags: bool = ...,
-        timeout: "JobTimeoutTypeDef" = ...,
+        timeout: JobTimeoutTypeDef = ...,
         tags: Mapping[str, str] = ...,
         platformCapabilities: Sequence[PlatformCapabilityType] = ...
     ) -> RegisterJobDefinitionResponseTypeDef:
@@ -340,14 +340,14 @@ class BatchClient(BaseClient):
         jobDefinition: str,
         shareIdentifier: str = ...,
         schedulingPriorityOverride: int = ...,
-        arrayProperties: "ArrayPropertiesTypeDef" = ...,
-        dependsOn: Sequence["JobDependencyTypeDef"] = ...,
+        arrayProperties: ArrayPropertiesTypeDef = ...,
+        dependsOn: Sequence[JobDependencyTypeDef] = ...,
         parameters: Mapping[str, str] = ...,
-        containerOverrides: "ContainerOverridesTypeDef" = ...,
-        nodeOverrides: "NodeOverridesTypeDef" = ...,
-        retryStrategy: "RetryStrategyTypeDef" = ...,
+        containerOverrides: ContainerOverridesTypeDef = ...,
+        nodeOverrides: NodeOverridesTypeDef = ...,
+        retryStrategy: RetryStrategyTypeDef = ...,
         propagateTags: bool = ...,
-        timeout: "JobTimeoutTypeDef" = ...,
+        timeout: JobTimeoutTypeDef = ...,
         tags: Mapping[str, str] = ...
     ) -> SubmitJobResponseTypeDef:
         """
@@ -387,9 +387,9 @@ class BatchClient(BaseClient):
         computeEnvironment: str,
         state: CEStateType = ...,
         unmanagedvCpus: int = ...,
-        computeResources: "ComputeResourceUpdateTypeDef" = ...,
+        computeResources: ComputeResourceUpdateTypeDef = ...,
         serviceRole: str = ...,
-        updatePolicy: "UpdatePolicyTypeDef" = ...
+        updatePolicy: UpdatePolicyTypeDef = ...
     ) -> UpdateComputeEnvironmentResponseTypeDef:
         """
         Updates an Batch compute environment.
@@ -405,7 +405,7 @@ class BatchClient(BaseClient):
         state: JQStateType = ...,
         schedulingPolicyArn: str = ...,
         priority: int = ...,
-        computeEnvironmentOrder: Sequence["ComputeEnvironmentOrderTypeDef"] = ...
+        computeEnvironmentOrder: Sequence[ComputeEnvironmentOrderTypeDef] = ...
     ) -> UpdateJobQueueResponseTypeDef:
         """
         Updates a job queue.
@@ -415,7 +415,7 @@ class BatchClient(BaseClient):
         """
 
     def update_scheduling_policy(
-        self, *, arn: str, fairsharePolicy: "FairsharePolicyTypeDef" = ...
+        self, *, arn: str, fairsharePolicy: FairsharePolicyTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Updates a scheduling policy.
